#!/usr/bin/perl -w

######################################################
#
#	Example of wrapper exploration
#
#	This script explore server performance between s1 and s2
#	and produce a normalized TCO and a normalized environmental impact
#	for each configuration in a file $filename.txt
#
#
######################################################

use strict;

######################################################
#
# $basedir VARIABLE TO MODIFY if you change the 
# organization of directories
#
# put the basedir of EETCO in $basedir
# example: my $basedir="/home/user/eetco/";
#
######################################################

my $basedir="../../";

#to get the current dir
my $currentdir=`pwd`;
chomp $currentdir;

######################################################
#
# The wrapper exploration start here
#
######################################################

#output file's name  without extension
my $filename="epc_performance";

#legende
my $legende="#epc \t normalized TCO \t normalized env impact\n";

#number of s2 servers
my $nbserver_ref=50000;



#open outputfile and print the legende
open(OUTPUTFILE,">$currentdir/output/$filename.txt") || die ("Error when opening $currentdir/output/$filename.txt") ;
print(OUTPUTFILE "$legende");

#goto the main directory to call the enterprise tool
if($basedir eq "")
{
	print("Please, set the \$basedir variable before using this script\n");
	exit(0);
}
chdir($basedir) or die "$!";


############################################################
#get the reference tco value and env impact reference value
############################################################

#clean the previous configuration file
if (-e "$currentdir/s1.params") 
{
	system("rm $currentdir/s1.params");
}
if (-e "$currentdir/s2.params") 
{
	system("rm $currentdir/s2.params");
}
if (-e "$currentdir/dc.params") 
{
	system("rm $currentdir/dc.params");
}

#generate the current configuration files
system("cat $currentdir/template/s2_template.params | sed -e 's/XXSERVERS/$nbserver_ref/g'  > $currentdir/s2.params");
system("cp  $currentdir/template/dc_template.params $currentdir/dc.params");

#call the kernel and keep the output
system("./eetco.pl $currentdir/dc.params $currentdir/s2.params > $currentdir/output/s2.value");
my $tco_ref=`cat $currentdir/output/s2.value | grep tco | gawk '{print \$2}'`;
chomp $tco_ref;
my $env_impact_ref = `cat $currentdir/output/s2.value | grep co2peryr | gawk '{print \$2}'`;
chomp $env_impact_ref;

############################################################
#exploration loop
############################################################
foreach my $epc(1..8)
{
	my $nbserver=$nbserver_ref*$epc;
	
	#clean the previous configuration file
	if (-e "$currentdir/s1.params") 
	{
		system("rm $currentdir/s1.params");
	}
	if (-e "$currentdir/s2.params") 
	{
		system("rm $currentdir/s2.params");
	}
	if (-e "$currentdir/dc.params") 
	{
		system("rm $currentdir/dc.params");
	}
	
	
	#generate the current configuration files
	system("cat $currentdir/template/s1_template.params | sed -e 's/XXSERVERS/$nbserver/g'  > $currentdir/s1.params");
	system("cp  $currentdir/template/dc_template.params $currentdir/dc.params");
	
	#call the enterprise tool and keep the output
	system("./eetco.pl $currentdir/dc.params $currentdir/s1.params > $currentdir/output/s1.$epc.value");
	
	#get the TCO value
	my $tco=`cat $currentdir/output/s1.$epc.value | grep tco | gawk '{print \$2}'`;
	chomp $tco;
	my $env_impact = `cat $currentdir/output/s1.$epc.value | grep co2peryr | gawk '{print \$2}'`;
	chomp $env_impact;

	my $normalized_tco=$tco/$tco_ref;
	my $normalized_env_impact=$env_impact/$env_impact_ref;
	
	print(OUTPUTFILE "$epc \t $normalized_tco \t $normalized_env_impact\n");
}

close OUTPUTFILE;

#keep the output file in the current directory
system("cp $currentdir/output/$filename.txt $currentdir/$filename.txt");

#go back to the current dir
chdir($currentdir) or die "$!";


####################################################
# gnulpot call
####################################################

#if (-e "./plot.plot") 
#{
#	system("rm ./plot.plot");
#}	

#system("cat ./template/gnuplot_template.plot | sed -e 's/XXNAME/$filename/g' > ./plot.plot");

#system("gnuplot <plot.plot");


####################################################
# clean
####################################################
#system("rm ./plot.plot");
system("rm ./dc.params");
system("rm ./s*.params");
system("rm ./output/*");
#system("rm $currentdir/$filename.txt");
