#!/usr/bin/perl -w

######################################################
#
#	Example of wrapper exploration
#
#	This script explore pvf vs. processor cost
#	and produce a normalized TCO and normalized environmental impact
#	for each configuration in a file $filename.txt
#
#
######################################################

use strict;

######################################################
#
# $basedir VARIABLE TO MODIFY if you change the 
# organization of directories
#
# put the basedir of the tco enterprise tool in $basedir
# example: my $basedir="/home/user/tco/enterprise/";
#
######################################################

my $basedir="../../";

#to get the current dir
my $currentdir=`pwd`;
chomp $currentdir;

######################################################
#
# The wrapper exploration start here
#
######################################################

####################################################
# initialisation phase
####################################################

#check valid input
my $argv_size = scalar @ARGV;
if ($argv_size != 2)
{
	print "usage: ./pvf_vs_price.pl <reference price> <coefficient reduction factor n>\n";
	exit(0);
}

my $price_ref=$ARGV[0];
my $n_coef=$ARGV[1];

#output file's name  without extension
my $filename="pvf_vs_price_.$price_ref.$n_coef";

my $legende="#pvf \t normalized TCO \t normalized env impact\n";



#open outputfile and print the legende
open(OUTPUTFILE,">$currentdir/output/$filename.txt") || die ("Error when opening $currentdir/output/$filename.txt") ;
print(OUTPUTFILE "$legende");

#goto the main directory to call the enterprise tool
if($basedir eq "")
{
	print("Please, set the \$basedir variable before using this script\n");
	exit(0);
}
chdir($basedir) or die "$!";


####################################################
# main exploration loop
####################################################

my $first=1;
my $tco_ref=0;
my $co2_ref=0;

my @pvfs=("0","0.01","0.02","0.03","0.04","0.05","0.06","0.07","0.08","0.09","0.1");


foreach my $pvf (@pvfs)
{
	
	my $price= $price_ref * (1/(1+$pvf)**$n_coef);
	
	#clean the previous configuration file
	if (-e "$currentdir/s.params") 
	{
		system("rm $currentdir/s.params");
	}
	if (-e "$currentdir/dc.params") 
	{
		system("rm $currentdir/dc.params");
	}
	
	#generate the current configuration file
	system("cp $currentdir/template/dc_template.params $currentdir/dc.params");
	system("cat $currentdir/template/s_template.params | sed -e 's/XXPRICE/$price/g' | sed -e 's/XXPVF/$pvf/g'  > $currentdir/s.params");
	
	#call the enterprise tool and keep the output
	system("./eetco.pl $currentdir/dc.params $currentdir/s.params  > $currentdir/output/$pvf.res");
	
	#get the TCO value
	my $tco=`cat $currentdir/output/$pvf.res | grep tco | gawk '{print \$2}'`;
	chomp $tco;
	my $co2=`cat $currentdir/output/$pvf.res | grep co2peryr | gawk '{print \$2}'`;
	chomp $co2;
	
	if($first==1) #if it is the first iteration, keep the reference values to normalized
	{
		$first=0;
		$tco_ref=$tco;
		$co2_ref=$co2;
	}
	
	my $normalized_tco=$tco/$tco_ref;
	
	my $normalized_co2 = $co2/$co2_ref;
	
	print(OUTPUTFILE "$pvf\t;\t$normalized_tco\t;\t$normalized_co2\n");
}

close(OUTPUTFILE);

#keep the output file in the current directory
system("cp $currentdir/output/$filename.txt $currentdir/$filename.txt");

#go back to the current dir
chdir($currentdir) or die "$!";

####################################################
# gnulpot call
####################################################

#if (-e "./plot.plot") 
#{
#	system("rm ./plot.plot");
#}	
#
#system("cat ./template/gnuplot_template.plot | sed -e 's/XXNAME/$filename/g' > ./plot.plot");
#
#system("gnuplot <plot.plot");


####################################################
# clean
####################################################
#system("rm ./plot.plot");
system("rm ./dc.params");
system("rm ./s.params");
system("rm ./output/*");
#system("rm $currentdir/$filename.txt");
